@@ -93,11 +93,11 @@ class IndexedSequence(SageObject):
 
     INPUT:
 
-    - ``L`` -- A list
+    - ``L`` -- list
 
-    - ``index_object`` must be a Sage object with an ``__iter__`` method
+    - ``index_object`` -- must be a Sage object with an ``__iter__`` method
       containing the same number of elements as ``self``, which is a
-      list of elements taken from a field.
+      list of elements taken from a field
     """
     def __init__(self, L, index_object):
         r"""
@@ -203,7 +203,7 @@ class IndexedSequence(SageObject):
 
     def _repr_(self):
         """
-        Implements print method.
+        Implement print method.
 
         EXAMPLES::
 
@@ -474,12 +474,10 @@ class IndexedSequence(SageObject):
 
         INPUT:
 
-        - ``other`` --  a collection of elements of a ring with
+        - ``other`` -- a collection of elements of a ring with
           index set a finite abelian group (under `+`)
 
-        OUTPUT:
-
-        The Dirichlet convolution of ``self`` and ``other``.
+        OUTPUT: the Dirichlet convolution of ``self`` and ``other``
 
         EXAMPLES::
 
@@ -533,11 +531,9 @@ class IndexedSequence(SageObject):
 
         INPUT:
 
-        - ``other`` --  a sequence of elements of `\CC`, `\RR` or `\GF{q}`
+        - ``other`` -- a sequence of elements of `\CC`, `\RR` or `\GF{q}`
 
-        OUTPUT:
-
-        The Dirichlet convolution of ``self`` and ``other``.
+        OUTPUT: the Dirichlet convolution of ``self`` and ``other``
 
         EXAMPLES::
 
@@ -578,7 +574,7 @@ class IndexedSequence(SageObject):
 
     def __mul__(self, other):
         """
-        Implements scalar multiplication (on the right).
+        Implement scalar multiplication (on the right).
 
         EXAMPLES::
 
@@ -598,7 +594,7 @@ class IndexedSequence(SageObject):
 
     def __eq__(self, other):
         """
-        Implements boolean equals.
+        Implement boolean equals.
 
         EXAMPLES::
 
@@ -668,7 +664,7 @@ class IndexedSequence(SageObject):
 
     def ifft(self):
         """
-        Implements the gsl ``FastFourierTransform.inverse`` in
+        Implement the gsl ``FastFourierTransform.inverse`` in
         :mod:`~sage.calculus.transforms.fft`.
 
         If the number of sample points in the input is a power of 2
@@ -703,7 +699,7 @@ class IndexedSequence(SageObject):
         a.inverse_transform()
         return IndexedSequence([a[j][0] + I * a[j][1] for j in J], J)
 
-    def dwt(self, other="haar", wavelet_k=2):
+    def dwt(self, other='haar', wavelet_k=2):
         r"""
         Wraps the gsl ``WaveletTransform.forward`` in :mod:`~sage.calculus.transforms.dwt`
         (written by Joshua Kantor). Assumes the length of the sample is a
@@ -720,9 +716,9 @@ class IndexedSequence(SageObject):
           * ``'bspline'``
           * ``'bspline_centered'``
 
-        - ``wavelet_k`` -- For daubechies wavelets, ``wavelet_k`` specifies a
-          daubechie wavelet with `k/2` vanishing moments.
-          `k = 4,6,...,20` for `k` even are the only ones implemented.
+        - ``wavelet_k`` -- for daubechies wavelets, ``wavelet_k`` specifies a
+          daubechie wavelet with `k/2` vanishing moments;
+          `k = 4,6,...,20` for `k` even are the only ones implemented
 
           For Haar wavelets, ``wavelet_k`` must be 2.
 
@@ -767,9 +763,9 @@ class IndexedSequence(SageObject):
         a.forward_transform()
         return IndexedSequence([RR(a[j]) for j in J], J)
 
-    def idwt(self, other="haar", wavelet_k=2):
+    def idwt(self, other='haar', wavelet_k=2):
         r"""
-        Implements the gsl ``WaveletTransform.backward()`` in
+        Implement the gsl ``WaveletTransform.backward()`` in
         :mod:`~sage.calculus.transforms.dwt`.
 
         Assumes the length of the sample is a power of 2. Uses the
@@ -777,18 +773,18 @@ class IndexedSequence(SageObject):
 
         INPUT:
 
-        - ``other`` -- Must be one of the following:
+        - ``other`` -- must be one of the following:
 
-          * ``"haar"``
-          * ``"daubechies"``
-          * ``"daubechies_centered"``
-          * ``"haar_centered"``
-          * ``"bspline"``
-          * ``"bspline_centered"``
+          * ``'haar'``
+          * ``'daubechies'``
+          * ``'daubechies_centered'``
+          * ``'haar_centered'``
+          * ``'bspline'``
+          * ``'bspline_centered'``
 
-        - ``wavelet_k`` -- For daubechies wavelets, ``wavelet_k`` specifies a
-          daubechie wavelet with `k/2` vanishing moments.
-          `k = 4,6,...,20` for `k` even are the only ones implemented.
+        - ``wavelet_k`` -- for daubechies wavelets, ``wavelet_k`` specifies a
+          daubechie wavelet with `k/2` vanishing moments;
+          `k = 4,6,...,20` for `k` even are the only ones implemented
 
           For Haar wavelets, ``wavelet_k`` must be 2.
 
