@@ -1,4 +1,3 @@
-# sage_setup: distribution = sagemath-categories
 # sage.doctest: needs sage.graphs sage.combinat
 r"""
 Classical Crystals
@@ -65,6 +64,8 @@ class ClassicalCrystals(Category_singleton):
         running ._test_new() . . . pass
         running ._test_not_implemented_methods() . . . pass
         running ._test_pickling() . . . pass
+        running ._test_random() . . . pass
+        running ._test_rank() . . . pass
         running ._test_some_elements() . . . pass
         running ._test_stembridge_local_axioms() . . . pass
     """
@@ -288,6 +289,8 @@ class ClassicalCrystals(Category_singleton):
                 running ._test_new() . . . pass
                 running ._test_not_implemented_methods() . . . pass
                 running ._test_pickling() . . . pass
+                running ._test_random() . . . pass
+                running ._test_rank() . . . pass
                 running ._test_some_elements() . . . pass
                 running ._test_stembridge_local_axioms() . . . pass
 
@@ -317,6 +320,8 @@ class ClassicalCrystals(Category_singleton):
                 running ._test_new() . . . pass
                 running ._test_not_implemented_methods() . . . pass
                 running ._test_pickling() . . . pass
+                running ._test_random() . . . pass
+                running ._test_rank() . . . pass
                 running ._test_some_elements() . . . pass
                 running ._test_stembridge_local_axioms() . . . pass
 
@@ -371,6 +376,8 @@ class ClassicalCrystals(Category_singleton):
                 running ._test_new() . . . pass
                 running ._test_not_implemented_methods() . . . pass
                 running ._test_pickling() . . . pass
+                running ._test_random() . . . pass
+                running ._test_rank() . . . pass
                 running ._test_some_elements() . . . pass
                 running ._test_stembridge_local_axioms() . . . pass
 
